pub struct Metrics(/* private fields */);Methods from Deref<Target = PrometheusHandle>
Sourcepub fn render(&self) -> String
pub fn render(&self) -> String
Takes a snapshot of the metrics held by the recorder and generates a payload conforming to the Prometheus exposition format.
Sourcepub fn run_upkeep(&self)
pub fn run_upkeep(&self)
Performs upkeeping operations to ensure metrics held by recorder are up-to-date and do not grow unboundedly.